summaryrefslogtreecommitdiffstats
path: root/src/script
diff options
context:
space:
mode:
authorkrzys-h <krzys_h@interia.pl>2013-05-18 17:01:52 +0200
committerkrzys-h <krzys_h@interia.pl>2013-05-18 18:04:48 +0200
commitd0de6a88ba5095c4d485e281e6fb3e804b0c21b6 (patch)
tree53e5ab0fa3fc26a23ed37b8ff5e5f9e4b376dc2e /src/script
parent8004e689481d01decbde351d1925e0efe23daf94 (diff)
downloadcolobot-d0de6a88ba5095c4d485e281e6fb3e804b0c21b6.tar.gz
colobot-d0de6a88ba5095c4d485e281e6fb3e804b0c21b6.tar.bz2
colobot-d0de6a88ba5095c4d485e281e6fb3e804b0c21b6.zip
Renamed destroy() -> delete()
Diffstat (limited to 'src/script')
-rw-r--r--src/script/script.cpp10
-rw-r--r--src/script/script.h4
2 files changed, 7 insertions, 7 deletions
diff --git a/src/script/script.h b/src/script/script.h
index 62e95b3..ae9011b 100644
--- a/src/script/script.h
+++ b/src/script/script.h
@@ -101,7 +101,7 @@ private:
static CBotTypResult cEndMission(CBotVar* &var, void* user);
static CBotTypResult cPlayMusic(CBotVar* &var, void* user);
static CBotTypResult cGetObject(CBotVar* &var, void* user);
- static CBotTypResult cDestroy(CBotVar* &var, void* user);
+ static CBotTypResult cDelete(CBotVar* &var, void* user);
static CBotTypResult cSearch(CBotVar* &var, void* user);
static CBotTypResult cRadar(CBotVar* &var, void* user);
static CBotTypResult cDetect(CBotVar* &var, void* user);
@@ -146,7 +146,7 @@ private:
static bool rSetResearchDone(CBotVar* var, CBotVar* result, int& exception, void* user);
static bool rGetObjectById(CBotVar* var, CBotVar* result, int& exception, void* user);
static bool rGetObject(CBotVar* var, CBotVar* result, int& exception, void* user);
- static bool rDestroy(CBotVar* var, CBotVar* result, int& exception, void* user);
+ static bool rDelete(CBotVar* var, CBotVar* result, int& exception, void* user);
static bool rSearch(CBotVar* var, CBotVar* result, int& exception, void* user);
static bool rRadar(CBotVar* var, CBotVar* result, int& exception, void* user);
static bool rDetect(CBotVar* var, CBotVar* result, int& exception, void* user);
diff --git a/src/script/script.cpp b/src/script/script.cpp
index 31ede8d..0271eb6 100644
--- a/src/script/script.cpp
+++ b/src/script/script.cpp
@@ -695,9 +695,9 @@ bool CScript::rFactory(CBotVar* thisclass, CBotVar* var, CBotVar* result, int& e
return true;
}
-// Compilation of the instruction "destroy(rank[, exploType[, force]])".
+// Compilation of the instruction "delete(rank[, exploType[, force]])".
-CBotTypResult CScript::cDestroy(CBotVar* &var, void* user)
+CBotTypResult CScript::cDelete(CBotVar* &var, void* user)
{
if ( var == 0 ) return CBotTypResult(CBotErrLowParam);
@@ -719,9 +719,9 @@ CBotTypResult CScript::cDestroy(CBotVar* &var, void* user)
return CBotTypResult(CBotTypFloat);
}
-// Instruction "destroy(rank[, exploType[, force]])".
+// Instruction "delete(rank[, exploType[, force]])".
-bool CScript::rDestroy(CBotVar* var, CBotVar* result, int& exception, void* user)
+bool CScript::rDelete(CBotVar* var, CBotVar* result, int& exception, void* user)
{
CObject* pObj;
int rank;
@@ -3320,7 +3320,7 @@ void CScript::InitFonctions()
CBotProgram::AddFunction("retobject", rGetObject, CScript::cGetObject);
CBotProgram::AddFunction("retobjectbyid", rGetObjectById, CScript::cGetObject);
- CBotProgram::AddFunction("destroy", rDestroy, CScript::cDestroy);
+ CBotProgram::AddFunction("delete", rDelete, CScript::cDelete);
CBotProgram::AddFunction("search", rSearch, CScript::cSearch);
CBotProgram::AddFunction("radar", rRadar, CScript::cRadar);
CBotProgram::AddFunction("detect", rDetect, CScript::cDetect);